[][src]Enum mini_haskell::error::Error

pub enum Error {
    InvalidUTF8(Vec<u8>),
    InputFailure(Error),
    InvalidChar(char),
    InvalidToken(LexError),
    IncompleteLexeme(LexemeType),
    FloatOutOfBound(BigInt),
    CharOutOfBound(BigInt),
}

An exhaustive list of compiler errors.

Variants

InvalidUTF8(Vec<u8>)

An invalid UTF-8 sequence.

InputFailure(Error)

A failure during the input process.

InvalidChar(char)

A Unicode character not accepted by the Haskell language.

InvalidToken(LexError)

An error during the tokenization process.

IncompleteLexeme(LexemeType)

A lexeme ended prematurely, e.g. EOF in a block comment.

FloatOutOfBound(BigInt)

A float literal is too large (or small) to represent.

Note:

CharOutOfBound(BigInt)

A character/string literal contains a Unicode character out of bound.