[−][src]Enum mini_haskell::error::Error
An exhaustive list of compiler errors.
Variants
An invalid UTF-8 sequence.
InputFailure(Error)A failure during the input process.
InvalidChar(char)A Unicode character not accepted by the Haskell language.
InvalidToken(LexError)An error during the tokenization process.
IncompleteLexeme(LexemeType)A lexeme ended prematurely, e.g. EOF in a block comment.
FloatOutOfBound(BigInt)A float literal is too large (or small) to represent.
Note:
- maximum value for IEEE 754 64-bit double is approximately 1.8e308;
- to prevent loss of precision, maximum value to store in IEEE 754 64-bit double is 2^53;
Rationalwith an exponent 4096 takes approximately 13.3KiB to store;- large float literals may eventually exhaust the usable memory of the compiler;
Rationalis probably not a good representation for large floats;
CharOutOfBound(BigInt)A character/string literal contains a Unicode character out of bound.